@@ -15,7 +15,8 @@ extern "C" {
     {"gibbsA0.cpp",(DL_FUNC) &gibbsA0, 6},
     {"log.marginal.A0k",(DL_FUNC) &log_marg_A0k, 9},
     {"BHLK.filter.cpp", (DL_FUNC) &BHLKR, 7},
-    {"SS.draw.cpp", (DL_FUNC) &SSdraw, 7},
+    //{"SS.draw.cpp", (DL_FUNC) &SSdraw, 7},
+    {"SS.newdraw.cpp", (DL_FUNC) &newSSdraw, 7},
     {"bingen.cpp", (DL_FUNC) &bingen, 3},
     //    {"SS.sum.cpp", (DL_FUNC) &SSsumR, 1},
     //    {"SS.mean.cpp",(DL_FUNC) &SSmeanR, 2},
